function [LS,LN] = Func_AxisLabel(NL,B,NC)
%
%   [LS,LN] = Func_AxisLabel(NL,B,NC)
%
%   Function that automatically compute the labels to be located inside the
%   y or x axis of a given chart. The number of labels to be created are
%   indicated via the NL parameter. Instead B is the boundary of the axis.
%
%   @param NL   :   Number of label that should be located inside the axis.
%                   This parameter needs to be always odd.
%   @param B    :   Boundaries from which compute the labels.
%   @param NC   :   Number of char that each label should be made up with.
%   
%   @output LS  :   Strings of the visualized label in the y or x axis.
%   @output LN  :   Numerical version of the previous mentioned labels.
%
% PhD Student Martin Matteo
% University of Padova
% Department of Information Engineering

LN = zeros(NL,1);
LN(1) = B(1) + (B(end)-B(1))/2; NL = NL - 1;
for iL = 2:1:2+NL/2
    LN(iL) = LN(1) + (iL-1)*((B(end)-B(1))/2)/(NL/2 + 1);
end
for iL = 2+NL/2:1:NL+1
    LN(iL) = LN(1) + (iL-(2+NL))*((B(end)-B(1))/2)/(NL/2 + 1);
end
LN = sort(LN);

LS = {};
for iL = 1:1:NL+1
    LS{iL} = num2str(round(LN(iL),NC));
end

end