function dq = Func_LAV_5D(t,q,param)

% DYNAMICAL VARIABLES - Associations
V = q(1); h = q(2); s = q(3); r = q(4); w = q(5);

% PARAMETERS - External Stimulus
IApp  = param.IApp; cAMP  = param.cAMP;

% PARAMETERS - Conductances
gNaF  = param.gNaF;  gNaP = param.gNaP; gKS = param.gKS;
gL    = param.gL;    gHCN = param.gHCN; gM  = param.gM;
DgHCN = param.DgHCN; DgM  = param.DgM;

% PARAMETERS - Reverse Potential
EK  = param.EK;  EHCN = param.EHCN; 
ENa = param.ENa; ELK  = param.ELK;

% PARAMETERS - Temperature Scaling Factors
Ph = param.Ph; Ps  = param.Ps;  Pr = param.Pr; Cm = param.Cm;

% REACTION RATES - M Activation Variable
Am = (1.86*(V + 25.4))/(1 - exp(-(V + 25.4)/10.3));
Bm = (-0.086*(V + 29.7))/(1 - exp((V + 29.7)/9.16));
mInf = Am/(Am+Bm);

% REACTION RATES - H Activation Variable
Ah = (-0.0336*(V + 118))/(1 - exp((V + 118)/11));
Bh = 2.3/(1 + exp(-(V + 35.8)/13.4));
hInf = Ah/(Ah+Bh);
hTau = 1/(Ph*(Ah+Bh));

% REACTION RATES - N Activation Variable
An = (0.186*(V + 48.4))/(1 - exp(-(V + 48.4)/10.3));
Bn = (-0.0086*(V + 42.7))/(1 - exp((V + 42.7)/9.16));
nInf = An/(An+Bn);

% REACTION RATES - S Activation Variable
As = (0.00122*(V + 19.5))/(1 - exp(-(V + 19.5)/23.6));
Bs = (-0.000739*(V + 87.1))/(1 - exp((V + 87.1)/21.8));
sInf = As/(As+Bs);
sTau = 1/(Ps*(As+Bs));

% REACTION RATE - R Activation Variable
Ar = (0.007*exp(-(V+95*cAMP+103.5*(1-cAMP))/19));
Br = (0.007*exp((V+95*cAMP+103.5*(1-cAMP))/22));
rInf = Ar/(Ar+Br);
rTau = 1/(Pr*(Ar+Br));

% IONIC CURRENTS - Computation
INaF = gNaF*(mInf^3)*h*(V - ENa);
INaP = gNaP*(nInf^3)*(V - ENa);
IKS  = gKS*s*(V - EK);
IL   = gL*(V - ELK);
IHCN = (gHCN + cAMP*DgHCN)*r*(V - EHCN);
IM   = (gM + cAMP*DgM)*w*(V - EK);

% REACTION RATES - W Activation Variable
wInf = 1/(1 + exp(-(V+35)/10));
wTau = 400/(3.3*exp((V+35)/20) + exp(-(V+35)/20));

% ODEs
dV = (1/Cm)*( - INaF - INaP - IKS - IL - IHCN - IM + IApp);
dh = (hInf - h)/hTau; ds = (sInf - s)/sTau;
dr = (rInf - r)/rTau; dw = (wInf - w)/wTau;

% DYNAMICAL VARIABLES - Associations
dq = [dV, dh, ds, dr, dw]';

end