function dq = Func_LAV_3D(t,q,param)

% DYNAMICAL VARIABLES - Associations
V = q(1); h = q(2); s = q(3);

% PARAMETERS - External Stimulus
IApp  = param.IApp;

% PARAMETERS - Conductances
gNaF  = param.gNaF;  gNaP = param.gNaP; gKS = param.gKS;
gL    = param.gL;    gHCN = param.gHCN; gM  = param.gM;

% PARAMETERS - Reverse Potential
EK  = param.EK;  EHCN = param.EHCN; 
ENa = param.ENa; ELK  = param.ELK;

% PARAMETERS - Temperature Scaling Factors
Ph = param.Ph; Ps  = param.Ps;  Pr = param.Pr; Cm = param.Cm;

% PARAMETERS - Activation parameters HCN and M channels
r = param.r; w = param.w;

% REACTION RATES - M Activation Variable
Am = (1.86*(V + 25.4))/(1 - exp(-(V + 25.4)/10.3));
Bm = (-0.086*(V + 29.7))/(1 - exp((V + 29.7)/9.16));
mInf = Am/(Am+Bm);

% REACTION RATES - H Activation Variable
Ah = (-0.0336*(V + 118))/(1 - exp((V + 118)/11));
Bh = 2.3/(1 + exp(-(V + 35.8)/13.4));
hInf = Ah/(Ah+Bh);
hTau = 1/(Ph*(Ah+Bh));

% REACTION RATES - N Activation Variable
An = (0.186*(V + 48.4))/(1 - exp(-(V + 48.4)/10.3));
Bn = (-0.0086*(V + 42.7))/(1 - exp((V + 42.7)/9.16));
nInf = An/(An+Bn);

% REACTION RATES - S Activation Variable
As = (0.00122*(V + 19.5))/(1 - exp(-(V + 19.5)/23.6));
Bs = (-0.000739*(V + 87.1))/(1 - exp((V + 87.1)/21.8));
sInf = As/(As+Bs);
sTau = 1/(Ps*(As+Bs));

% IONIC CURRENTS - Computation
INaF = gNaF*(mInf^3)*h*(V - ENa);
INaP = gNaP*(nInf^3)*(V - ENa);
IKS  = gKS*s*(V - EK);
IL   = gL*(V - ELK);
IHCN = gHCN*r*(V - EHCN);
IM   = gM*w*(V - EK);

% ODEs
dV = (1/Cm)*( - INaF - INaP - IKS - IL - IHCN - IM + IApp);
dh = (hInf - h)/hTau; ds = (sInf - s)/sTau;

% DYNAMICAL VARIABLES - Associations
dq = [dV, dh, ds]';

end