function S = Func_Simulate(Func,T,IC,VAR,param,Options,Event)
%
%   S = Func_Simulate(Func,T,IC,VAR,param,Options,Event)
%
%   DESCRIPTION:
%   Function that solve the model defined through ODEs contained inside the
%   specified function field via the usage of the ODE78 solver. This
%   function give as output the resulting values of each inspected variable
%   via a structure container.
%
%   FUNCTION INPUT/OUTPUT:
%   @param Func         :   Function handle that contains the ODE to be
%                           solved
%   @param T            :   TSPAN for ODE78
%   @param IC           :   IC for ODE78
%   @param VAR          :   Variables that should be recognized
%   @param param        :   Parameter structure
%   @param [Options]    :   Options for ODE78
%   @param Event        :   Additional field of the function to activate
%                           the retrival of event solutions.
%
%   @output S           :   Output structure
%   
%   S FIELDS:   t - Time vector     VAR - Each variable contained in VAR
%   
% Phd Student Martin Matteo
% University of Padova - Department of Information Engineering

% ================================ ODE ====================================
switch nargin
    case 5
        [t, s] = ode78(@(t,q)Func(t,q,param),T,IC);
    case 6
        [t, s] = ode78(@(t,q)Func(t,q,param),T,IC,Options);
    case 7
        [t, s, te, se, ie] = ode78(Func,T,IC,Options,param); 
        S.te = te; S.se = se; S.ie = ie;
end
S.t = t;

% ================================= OUTPUT ================================
for i = 1:1:size(s,2), eval(['S.',VAR{i},'=s(:,',num2str(i),');']); end

end