function FV = Func_FinalValue(Func,T,IC,VAR,param,Options)
%
%   FV = Func_FinalValue(Func,T,IC,VAR,param,Options)
%
%   DESCRIPTION:
%   Function that can identify retrive the coordinate of the final state of
%   the system during a simulation. The model considered can be passed in
%   input. All the other parameters wil be explained in the following of
%   the documentation.
%
%   FUNCTION INPUT/OUTPUT:
%   @param Func         :   Function handle of the model that should be
%                           solved
%   @param T            :   TSPAN for ODE78
%   @param IC           :   IC for ODE78
%   @param VAR          :   Variables that should be recognized
%   @param param        :   Parameter's model summarizing structure
%   @param Options      :   Options structure with which the model is
%                           solved.
%
%   @output FV          :   Final Values Output Vector
%   @output FS          :   Fianl Values Output Structure
%
% Phd Student Martin Matteo
% University of Padova - Department of Information Engineering

% ================================ ODE ====================================
switch nargin
    case 5, [~, s] = ode78(Func,T,IC,param);
    case 6, [~, s] = ode78(Func,T,IC,Options,param);
end

% =============================== OUTPUT ==================================
FV = s(end,:)';

end