function Func_SaveFigure(fig, opts, fileName)
%
%       Func_SaveFigure(fig, opts, fileName)
%
%   Function that facilitate the savage of the figure specified as
%   parameter of the function.
%
%   @param fig      :   Figure to export
%   @param opts     :   Options of the figure to be exported
%   @param fileName :   File name of the figure to be exported
%
% PhD Student Martin Matteo
% University of Padova - Department of Information Engineering

% WARNING - The method to move on top and on bottom the grid of the plot
%           independently from the box of the same will be no longer
%           supported in future version of Matlab. This function avoid the
%           display of the current error.
warning('off','all')

% ======================= HANDLING - CONSTANTS ============================
% Constants used to check the various types of object analysed through the 
% various children presented within the function. These are defined as 
% global for the whole set of function within this scope.
typeAxes        = 'matlab.graphics.axis.Axes';
typeTiledLayout = 'matlab.graphics.layout.TiledChartLayout';
typeWorldGroup  = 'matlab.graphics.primitive.world.Group';

% ======================== HANLDING - SIZE ================================
% Hanlding the size of the whole figure. The unit of measurement that it is
% specified as unit considered is the centimeter.
fig.Units       = 'centimeters';
fig.Position(3) = opts.width;
fig.Position(4) = opts.height;

% ====================== HANLDING - PROPERTY ==============================
% Handling property of the figure. The whole set of children components of
% a figure are deeply analysed. Specifically, we consider each children and
% we change the specified properties only when the considered children is
% of type axes.
figV = 'fig.Children'; Explode(figV,fig)

% ======================== EXPORTATION ====================================
% This part of the function export the figure only if the name of the
% figure itself is not empty.
fig.PaperPositionMode   = 'auto';
if not(isempty(fileName))
    print([fileName,opts.FileExtension], opts.FileType, '-r600')
end


    function Explode(figV,fig)
        ObjToModFont = eval(figV);
        if strcmp(class(ObjToModFont),typeAxes)
            SetObjGraphComp(ObjToModFont, @SetAxesProperty)
            SetObjGraphComp(ObjToModFont, @SetGridProperty)
        end
        if strcmp(class(ObjToModFont),typeTiledLayout)
            for i = 1:1:length(ObjToModFont)
                Explode([figV, '(',num2str(i),').Children'],fig)
            end
        end
        if strcmp(class(ObjToModFont),typeWorldGroup)
            for i = 1:1:length(ObjToModFont)
                Explode([figV,sprintf('(%i)',i)],fig)
            end
        end
    end

    function SetObjGraphComp(figV, f)
        if length(figV) == 1
            f(figV)
        else
            for i = 1:1:length(figV)
                f(figV(i))
            end
        end
    end

    function SetGridProperty(figV)
        set(figV, 'LooseInset',          max(get(figV,'TightInset'), 0.02), ...
                  'GridLineStyle',       opts.gridLineStyle,                ...
                  'YGrid',               'on',                              ...
                  'XGrid',               'on',                              ...
                  'GridLineStyle',       opts.gridLineStyle,                ...
                  'MinorGridLineStyle' , opts.minorGridLineStyle,           ...
                  'GridAlpha'          , opts.gridAlpha,                    ...
                  'MinorGridAlpha'     , opts.minorGridAlpha,               ...
                  'Box'                , 'on',                              ...
                  'Layer'              , 'top',                             ...
                  'ClippingStyle'      , 'rectangle')
        
        AX_ = struct(figV);
        AX_.XGridHandle.FrontMajorEdge.Layer = 'back';
        AX_.YGridHandle.FrontMajorEdge.Layer = 'back';
    end

    function SetAxesProperty(figV)
        set(figV,'FontName',opts.FontName,'FontSize',opts.FontSize);
    end

end



