function AP = Func_AP(param, VAR)
%
%   AP = Func_AP(param, VAR)
%   
%   Function that characterize the action potential activated from the
%   model in terms of minimum value assumed by the variables V, h and s
%   during the large spike.
%
%   @param param    :   Parameter structure
%   @param VAR      :   Variable cell vector
%
%   @output AP      :   Action potential structure
%
% PhD Student Martin Matteo
% Department of Information Engineering
% University of Padova

options = odeset('RelTol',1e-6,'AbsTol',1e-6);
S = Func_Simulate(@Func_LAV_3D,[0 450],[0; 0; 0],{'V','h','s'},param,options);

IT = S.t > 350;       S.V = S.V(IT); S.h = S.h(IT);  S.s = S.s(IT);
IM = islocalmax(S.V); P.V = S.V(IM); P.h = S.h(IM);  P.s = S.s(IM);

nPts = length(S.V);     IS   = P.V < 0; 
DIS  = diff(IS) == -1;  DISI = circshift(DIS,1);

for i = 1:1:length(VAR)
    eval(['AP.',VAR{i},' = min(P.',VAR{i},'(DISI));'])
end

end
