function S = Func_BVP(IC,FuncSys,param,VisualizeProgr,VisualizeEvol,VAR)
%
%   S = Func_BVP(IC,FuncSys,param,VisualizeProgr,VisualizeEvol,VAR)
%
%   Function that simulate the system solving the ODE as a boundary value
%   problem. The boundary final value is always associated to an event
%   specified in some additional function. Instead the initial condition
%   are passed as input argument of the function.
%
%   @param IC       :   Initial condition matrix
%   @param FuncSys  :   Function handle of the dynamical system to solve
%   @param param    :   Parameter structure for which execute simulation
%   @param Visualize:   Boolean parameter to turn on/off the visualization
%   @param Visualize:   Boolean parameter to turn on/off the visualization
%   @param VAR      :   Cell vector containing the variable that should be
%                       visualized.
%
%   @output S       :   Structure of simulations associated to each initial
%                       condition passed as function argument.
%
% PhD Student Martin Matteo
% Department of Information Engineering
% University of Padova

nIC = size(IC,1); 
S = {};

if VisualizeProgr, fprintf('BVP:\n'), end
for i = 1:1:nIC
    param.IC = IC(i,:)';
    Si = Func_Simulate(FuncSys,[param.TL param.TH],param.IC,param.VAR,param,param.options,1);
    EP.V = Si.V(end); EP.h = Si.h(end); EP.s = Si.s(end);
    R  = Func_DistancePlane(param.Sigma,Func_StructToVect(EP,{'h','V','s'}));
    if VisualizeProgr
        fprintf(['%i/%i - TH: %3.2f - EP: (%1.2f,%2.2f,%1.2f) ',...
            '[-,mV,-] - R: %3.2f\n'],i,nIC,Si.t(end),Si.h(end),Si.V(end),Si.s(end),R)
    end

    if VisualizeEvol
        hold on
        eval(sprintf('plot3(Si.%s,Si.%s,Si.%s,''LineWidth'',1.5,''LineStyle'',''-'',''Color'',''m'')'...
            ,VAR{1},VAR{2},VAR{3}))
        hold off
        drawnow
    end

    S{i} = Si;
end


end