function C = Func_BuildCanard(SCF, SCB, Fields)
%
%   C = Func_BuildCanard(SCF, SCB, Fields)
%
%   Function that build the canard solutions of the dynamical system to
%   better handle the crated data.
%
%   @param SCF   :   First part of the canard orbit. Forward integration
%                    solution.
%   @param SCB   :   Second part of the canard orbit. Backward integration
%                    solution.
%   @param Fields:   Fields that needed to be merged between the two
%                    structures SCF and SCB respectively.
%
%   @output C    :   Canard orbits structure. Each entry of the cell array
%                    contains a structure representative of the computed
%                    canard orbit.
%
% PhD Student Martin Matteo
% University of Padova
% Department of Information Engineering

% ===================== HYPERPARAMETERS: EXTRACTION =======================
% Extraction of the hyperparameters necessary to let the code be more
% readable inside its further sections.
nC = length(SCF);
nF = length(Fields);
C  = {};

% ===================== STRUCTURE: CONSTRUCTION ===========================
% Construction of the canard container by creating a new cell vector where
% each cell contain a simulation structure representative of a single
% canard orbit computed and stored inside the input of this function.
for iC = 1:1:nC
    for iF = 1:1:nF
        f = eval(['SCF{iC}.',Fields{iF},';']);
        b = eval(['SCB{iC}.',Fields{iF},';']);

        % ======================== GENERIC FIELD ==========================
        % The true statement of this if handles the generic field inside
        % the Fields structure to create the new one inside the canard
        % orbit variable.
        if not(strcmp(Fields{iF},'t'))
            b = b(1:end-1); 
            b = flipud(b);
        % ========================= TIME FIELD ============================
        % Time field handle. This few lines of code are necessary to handle
        % the time information passed inside this function, in particular
        % inside the SCF and SCB fields.
        else
            b = flipud(b);        nf = length(f); nb = length(b);       
            t = zeros(nf+nb-1,1); t(1:nf) = f;
            
            for ib = 1:1:nb-1
                dt = abs(b(ib))-abs(b(ib+1));
                t(nf+ib) = t(nf+ib-1) + dt;
            end
            f = []; b = t;
        end
        
        % ======================= MEMORIZATION ============================
        % Memorization of the newly created field inside the canard array.
        eval(['C{iC}.',Fields{iF},' = [f; b];'])
    end
end

end