function C = Func_ClassifyCanard(C,LAOTH)
%
%   C = Func_ClassifyCanard(C,LAOTH)
%
%   Function that classify the whole set of canard orbit passed inside the
%   cell array C. The structure inside each cell is a simulation one
%   therefore with fields such as V and t. Where the first refers to the
%   voltage instead the second to the time. To discriminate the number of
%   SAO inside each canard orbit an empirical threshold value is passed to
%   the function.
%
%   @param C    :   Canard cell array
%   @param LAOTH:   Large Amplitude Oscillation Threhsold
%
%   @output C   :   Augmented canard cell array
%
% PhD Student Martin Matteo
% University of Padova
% Department of Information Engineering

% =================== HYPERPARAMETERS: DEFINITION =========================
% Definition of the hyperparameters that will  be used inside further
% section of the code.
nC = length(C);

for iC = 1:1:nC
    % ==================== INFORMATION: RETRIVAL ==========================
    % Retrival of the most foundamental information, as instance the
    % indexes where the canard orbit present maximum, the one that exceeds
    % the LAO classification and then the extraction of the maximum peak
    % related to SAO.
    idxMMO = islocalmax(C{iC}.V);
    idxLAO = C{iC}.V > LAOTH;
    idxSAO = not(idxLAO) & idxMMO;
    
    % ======================= SAO: COMPUTATION ============================
    % Computation of the number of SAO prenseted inside the canard orbit.
    nSAO   = sum(idxSAO);

    % ======================= LEGEND: CONSTRUCTION ========================
    % Construction of the legend and the output additional classification
    % of the canard orbit.
    C{iC}.nSAO = nSAO;
    C{iC}.Leg  = sprintf('$\\xi_{%i}$',nSAO);
end

end