function C0 = Func_CommuteColorC0(C0, COLAB, COLRB)
%
%   C0 = Func_CommuteColorC0(C0, COLAB, COLRB)
%
%   Fuction that commute the color of C0 in both the attracting and
%   repelling branches.
%
%   @param C0   :   Critical manifold structure.
%   @param COLAB:   New RGB color of the attracting slow submanifold
%   @param COLRB:   New RGB color of the repelling slow submanifold
%
%   @output C0  :   New color coded critical manifold.
%
% PhD Student Martin Matteo
% University of Padova
% Department of Information Engineering

% ======================= SUBMANIFOLDS: RECOGNITION =======================
% Recognition of the slow manifold submanifolds depending on the color code
% used inisde the Critical manifold structure C field.
IDXAB = squeeze(C0.C(:,:,1) == 0 & C0.C(:,:,2) == 0 & C0.C(:,:,3) == 0);
IDXRB = squeeze(C0.C(:,:,1) == 1 & C0.C(:,:,2) == 0 & C0.C(:,:,3) == 0);

% ============================= HYPEPARAMETERS ============================
% Hyperparameters used inside the further section of the code.
nC = size(C0.C,3);

% ============================= COLOR-CODING ==============================
% Color coding of the critical manifold respect to the one passed as input
% to the function.
for iC = 1:1:nC
    C0Ci = C0.C(:,:,iC); 
    C0Ci(IDXAB) = COLAB(iC); C0Ci(IDXRB) = COLRB(iC);
    C0.C(:,:,iC) = C0Ci;
end

end