function C0 = Func_ComputeGeomC0(C0f,dVf,opts,VAR)
%
%   C0 = Func_ComputeGeomC0(C0f,dVf,opts,VAR)
%
%   Function that compute the geometry of the critical manifold C0.
%   
%   @param C0f  :   Critical manifold function handle
%   @param dVf  :   Function f derivative handle
%   @param opts :   Options structure
%   @param VAR  :   Variable cell vector
%
%   @output C0  :   Critical manifold structure
%
% PhD Student Martin Matteo
% Department of Information Engineering
% University of Padova

FLAG = 0;
if opts.C0.s(1) == opts.C0.s(2) || opts.C0.h(1) == opts.C0.h(2), FLAG = 1; end    

% ============================= AXES GENERATION ===========================
% Generation of the axes where the critical manifold should be computed.
% The resolution and the boundaries are specified inside the opts
% structure.
V = linspace(opts.C0.V(1),opts.C0.V(2),opts.nP)';
if strcmp('h',VAR)
    if FLAG,      h = opts.C0.h(1); end
    if not(FLAG), h = linspace(opts.C0.h(1),opts.C0.h(2),opts.nP)'; end    
end
if strcmp('s',VAR)
    if FLAG,      s = opts.C0.s(1); end
    if not(FLAG), s = linspace(opts.C0.s(1),opts.C0.s(2),opts.nP)'; end
end

% ====================== CRITICAL MANIFOLD COMPUTATION ====================
% Computation of the critical manifold which will be displayed inside the
% dedicated chart already open up.
if strcmp('h',VAR)
    if FLAG,      C0.V = V; C0.h = h*ones(opts.nP,1); end
    if not(FLAG), [C0.h, C0.V]  = meshgrid(h,V); end
    C0.s = C0f(C0.V,C0.h);
end
if strcmp('s',VAR)
    if FLAG,      C0.V = V; C0.s = s*ones(opts.nP,1); end
    if not(FLAG), [C0.V, C0.s]  = meshgrid(V,s); end
    C0.h = C0f(C0.V,C0.s);
end

Temp = dVf(C0.V,C0.h,C0.s) > 0;
if FLAG
   C0.C = Temp;
end
if not(FLAG)
    C0.C          = repmat(Temp, [1 1 3])*1;
    C0.C(:,:,2:3) = zeros(opts.nP,opts.nP,2);
end


end