function L = Func_ComputeIntersectionC0(Plane, C0f, dVf, opts)
%
%   L = Func_ComputeIntersectionC0(Plane, C0f, dVf, opts)
%
%   Function that compute the intersection of the critical manifold C0 with
%   the plane specified as input to this function.
%
%   @param Plane        :   Plane structure
%   @param C0f          :   Critical manifold function
%   @param dVf          :   Partial derivative of the f function to
%                           classify the critical manifold C0 points.
%   @param opts         :   Options structure
%
%   @output L           :   Intersection line structure
%
% PhD Student Martin Matteo
% Department of Information Engineering
% University of Padova

a = Plane.a; b = Plane.b; c = Plane.c; d = Plane.d;

if a ~= 0 && b == 0 && c == 0
    hB = -d/a; opts.C0.h = [hB hB];
    L  = Func_ComputeGeomC0(C0f,dVf,opts,'h');
end

if a == 0 && b == 0 && c ~= 0
    sB = -d/c; opts.C0.s = [sB sB];
    L  = Func_ComputeGeomC0(C0f,dVf,opts,'s');
end


end