function Plane = Func_ComputePlane(n,P)
%
%   Plane = Func_ComputePlane(n,P)
%
%   Computation of the plane that passes through P and have normal director
%   vector the one specified inside the n field.
%
%   @param n        :   Vector normal to the plane
%   @param P        :   Central point of the plane
%
%   @output Plane   :   Plane with both implicit and vectorial definition
%
% PhD Student Martin Matteo
% Department of Information Engineering
% University of Padova

% Parametric Definition
if not(n(1) == 0)
    n2 = n(2)/n(1);         n3 = n(3)/n(1);
    Plane.V1 = [-n2; 1; 0]; Plane.V1 = Plane.V1/norm(Plane.V1);
    Plane.V1 = Plane.V1 - ((Plane.V1'*n)/(n'*n))*n;
    Plane.V2 = [-n3; 0; 1]; Plane.V2 = Plane.V2/norm(Plane.V2);
    Plane.V2 = Plane.V2 - ((Plane.V2'*Plane.V1)/(Plane.V1'*Plane.V1))*Plane.V1;
end

if n(1) == 0
    n1 = n(1)/n(3);         n2 = n(2)/n(3);
    Plane.V1 = [0; 1; -n2]; Plane.V1 = Plane.V1/norm(Plane.V1);
    Plane.V1 = Plane.V1 - ((Plane.V1'*n)/(n'*n))*n;
    Plane.V2 = [1; 0; -n1]; Plane.V2 = Plane.V2/norm(Plane.V2);
    Plane.V2 = Plane.V2 - ((Plane.V2'*Plane.V1)/(Plane.V1'*Plane.V1))*Plane.V1;
end

% Implicit Definition
a = n(1);    b = n(2);    c = n(3); 
Plane.a = a; Plane.b = b; Plane.c = c; Plane.d = -(a*P(1)+b*P(2)+c*P(3));

end