function I = Func_ComputePlaneIntersection(Plane, S, P, E, isVisualProgression)
%
%   I = Func_ComputePlaneIntersection(Plane, S, P, E)
%
%   Function that compute the plane intersection with the structure S
%   representative of a simulation passed as input to this function.
%
%   @param Plane                :   Plane for which compute the projection
%   @param S                    :   Simulations structure
%   @param P                    :   Central point
%   @param E                    :   Event to retrieve
%   @param isVisualProgression  :   Track the progression of the
%                                   computation.
%
%   @output I       :   Intersection plane coordinates for each simulation
%
% PhD Student Martin Matteo
% Department of Information Engineering
% University of Padova

if nargin == 3, E = 1; end

% ===================== HYPERPARAMETERS: DEFINITION =======================
% Definition and extraction of important feature to let the code be more
% readable. Allocation of the foundamental variable space.
nP = length(S);
A  = [Plane.V1, Plane.V2];
Ad = decomposition(A);
x  = zeros(2,nP);

% ============================= REFERENCE CHANGE ==========================
% Change of the plane projection point coordinate by using the same
% specified inside the reference plane with origin over the point P.
for i = 1:1:nP

    % ========================== EVENT: EXTRACTION ========================
    % Extraction of the main events directly from the different simulations
    % structure passed as input to this function.   
    indexE      = find(S{i}.ie == E); 
    [~, indexT] = min(S{i}.te(indexE)); 
    index       = indexE(indexT);


    % ===================== DEBUG: TRACKING PROGRESSION ===================
    % Tracking the progression of the algorithm. This is used only for
    % debuggin purposes.
    if isVisualProgression
        fprintf('DEBUG - SIM: %i/%i - Events detected: %i - Typ 1: %i - Typ 2: %i\n',i,nP,length(S{i}.ie),sum(S{i}.ie == 1),sum(S{i}.ie == 2))
        fprintf('DEBUG - SIM: %i/%i - Event Number %i - Lenght Vector %i\n',i,nP,index,length(S{i}.ie))
    end

    % ====================== COORDINATE: CONVERSION =======================
    % Conversion of the coordinate via the dedicated matrix A specified
    % inside the beginning of this function. The new coordinate are the
    % scalar to be attributed to each A column such that the last
    % coordinate of the simulation is mapped inside the plane reference.
    b = [S{i}.se(index,2), S{i}.se(index,1), S{i}.se(index,3)]' - P;
    x(:,i) = Ad\b;
end

% ======================= OUTPUT: CONSTRUCTION ============================
% Construction of the output structure via a dedicated cycle. The new
% coordinates used are indicated with the variables x1 and x2 fields to the
% structure I passed as output of this function.
for i = 1:1:nP
    eval(['I{',num2str(i),'}.x1 = x(1,',num2str(i),');'])
    eval(['I{',num2str(i),'}.x2 = x(2,',num2str(i),');'])
end

end