function [ShiftX, ShiftY, ShiftZ] = Func_ComputeTransitionMatrices(MDs)
%
%   [ShiftX, ShiftY, ShiftZ] = Func_ComputeTransitionMatrices(MDs)
%
%   Function that compute the transition matrices to align the middle
%   points MDs such that, inside a four plot (2,2) visualization the
%   alignment achieved are the following:
%       I - II  : Vertical alignment
%       I - III : Horizontal alignment
%       II - IV : Horizontal alignment
%       III - IV: Vertical alignment
%
%   @param MDs  :   Middle points obtained as the point in between the
%                   equilibrium and the folded singularity of the system.
%
%   @output ShiftX: X - Shift matrix
%   @output ShiftY: Y - Shift matrix
%   @output ShiftZ: Z - Shift matrix
%
% PhD Student Martin Matteo
% University of Padova
% Department of Information Engineering

nC     = 4;
ShiftX = zeros(nC,1);
ShiftY = [0, 0, -(MDs{3}.s-MDs{1}.s), -(MDs{4}.s-MDs{2}.s)];
ShiftZ = [0, -(MDs{2}.V-MDs{1}.V), 0, -(MDs{4}.V-MDs{3}.V)];

end