function L = Func_CostCanard(p, param)
%
%   L = Func_CostCanard(p, param)
%
%   Cost function that should be optimized via the optimization problem
%   defined through the fmincon function. The cost is defined as the
%   distance between the plane projection of the forward and backward
%   computation.
%
%   @param p    :   Parameter to be changed in order to minimize the cost
%   @param param:   Parameter structure to simulate the model
%
%   @output L   :   Cost associated to the i-th iteration
%
% PhD Student Martin Matteo
% University of Padova
% Department of Information Engineering

    % IC - Definition
    ICF = [p(1);param.h0;param.C0s(p(1),param.h0)]';
    ICB = [p(2);param.C0h(p(2),param.s0);param.s0]';
    
    % BVP - Forward BVP
    param.isT = [1; 0]; param.TL = 0; param.TH = 100;
    SF = Func_BVP(ICF,@Func_LAV_3D,param,0,0,param.VAR);

    % BVP - Backward BVP
    param.isT = [1; 0]; param.TL = 0; param.TH = -100;
    SB = Func_BVP(ICB,@Func_LAV_3D,param,0,0,param.VAR);

    % EP - Definition
    EPF = [SF{1}.V(end); SF{1}.h(end); SF{1}.s(end)];
    EPB = [SB{1}.V(end); SB{1}.h(end); SB{1}.s(end)];

    % Cost Function - Computation
    L = norm(EPF - EPB);
end