function L = Func_CostCanardApproximation(p, param)
%
%   L = Func_CostCanardApproximation(p, param)
%
%   Cost function that should be optimized via the optimization problem
%   defined through the fmincon function. The cost is defined as the
%   distance between the plane projection of the forward and backward
%   computation.
%
%   @param p    :   Parameter to be changed in order to minimize the cost
%   @param param:   Parameter structure to simulate the model
%
%   @output L   :   Cost associated to the i-th iteration
%
% PhD Student Martin Matteo
% University of Padova
% Department of Information Engineering

    % IC - Definition
    ICF = [p(2),param.h0,param.C0s(p(2),param.h0)]';
    ICB = [p(1),param.C0h(p(1),param.s0),param.s0]';
    
    % BVP - Forward BVP
    param.D = param.DF; T = [0 100];
    SF = Func_Simulate(@Func_LAV_3D,T,ICF,param.VAR,param,param.options,true);

    % BVP - Backward BVP
    param.D = param.DB; T = [0 -100];
    SB = Func_Simulate(@Func_LAV_3D,T,ICB,param.VAR,param,param.options,true);

    % EP - Definition
    
    if length(SF.ie) == 1 && SF.ie == 1; EPF = SF.se; EPF(1) = EPF(1)/100;
    else, EPF = SF.se; EPF(1) = EPF(1)/100; end
    if length(SB.ie) == 1 && SB.ie == 1; EPB = SB.se; EPB(1) = EPB(1)/100;
    else, EPB = SB.se; EPB(1) = EPB(1)/100; end

    % Cost Function - Computation
    L = norm(EPF - EPB);
end