function L = Func_CreateCanardLegend(p,C,nCOL)
%
%   L = Func_CreateCanardLegend(p,C,nCOL)
%
%   Function that create the legend to be specified after having visualized
%   the canard orbit inside a given space.
%
%   @param p    :   Line handle that needed to be used inside the legend
%   @param C    :   Canard cell array
%   @param nCOL :   Number of columns that should be used inside the legend
%
%   @output L   :   Legend handle
%
% PhD Student Martin Matteo
% University of Padova
% Department of Information Engineering

% =================== HYPEPARAMETERS: DEFINITION ==========================
% Definition of the necessary hypeparameters to simplify the code
% readibility.
nC = length(C);

% ======================== LEGEND: CONSTRUCTION ===========================
% Construction of the legend cell array, by inserting in each entry the
% legend term specified inside the C i-th cell fields.
LC = {}; for iC = 1:1:nC, LC{iC} = C{iC}.Leg; end

% ========================= LEGEND: DEFINITION ============================
% Definition and visualization of the cell legend and storage of the legend
% handle to allow modification even outside the main function.
L = legend(p,LC,'NumColumns',nCOL,'Box','off',...
    'FontName','Times New Roman','FontSize',10,...
    'Location','southoutside','interpreter','latex');

end