function [V, isT, D] = Func_EventODECriticalManifold(t,q,param)
%
%   [V, isT, D] = Func_EventODECriticalManifold(t,q.param)
%
%   Event function used to detect the ODE termination once the model's
%   trajectory computed crosses the critical manifold C0.
%
%   @param t        :   Current instant of time inspected
%   @param q        :   Current state vector
%
%   @output V       :   Value of the function to be evaluated.
%   @output isT     :   Index representative if the i-th event should
%                       terminate or not the integration.
%   @output D       :   Direction from which appraoch the 0 of V.
%
% PhD Student Martin Matteo
% Department of Information Engineering
% University of Padova

hC0 = param.fC0h(q(1),q(3));
V   = (hC0 - q(2)).*(q(1)>0) + -1*(q(1)<0);
isT = 1;
D   = 0;

end