function [V, isT, D] = Func_EventODEDouble(t, q, param)
%
%   [V, isT, D] = Func_EventODEDouble(t, q, param)
%
%   Even function used by the ODE Event handler to terminate the
%   integration of a specified ODE file. The event that make the
%   integration terminate is defined as the passage through a specified
%   plane of the trajectory q.
%
%   @param t    :   Current instant of time
%   @param q    :   Current state vector
%   @param param:   Parameter structure
%
%   @output V   :   Value of the function which once zero stops the
%                   integration
%   @output isT :   Index which quantify the termination of the
%                   integration associated to the previous mentioned event.
%   @output D   :   Direction from which the occurance of 0 is considered.
%                  
% PhD Student Martin Matteo
% Department of Information Engineering
% University of Padova

q([1,2]) = q([2,1]);
V   = [Func_DistancePlane(param.SigmaFN,q);
       Func_DistancePlane(param.SigmaDW,q)];
isT = param.isT;
D = [0;0];

end