function [V, isT, D] = Func_EventODEStrongCanard(t, q, param)
%
%   [V, isT, D] = Func_EventODEStrongCanard(t, q, param)
%
%   Even function used by the ODE Event handler to terminate the
%   integration of a specified ODE file. The event that make the
%   integration to step consists in the crossing of the voltage VToCross
%   stored inside the param structure.
%
%   @param t    :   Current instant of time
%   @param q    :   Current state vector
%   @param param:   Parameter structure
%
%   @output V   :   Value of the function which once zero stops the
%                   integration
%   @output isT :   Index which quantify the termination of the
%                   integration associated to the previous mentioned event.
%   @output D   :   Direction from which the occurance of 0 is considered.
%                  
% PhD Student Martin Matteo
% Department of Information Engineering
% University of Padova

q([1,2]) = q([2,1]);

V        = q(2) - param.VToCross;

isT      = param.isT;

D        = param.D;

end