function [SFT] = Func_ManualFineTuning(S,opts)
%
%   [SFT] = Func_ManualFineTuning(S,opts)
%
%   Function that helps to manual fine tuning the slow manifold computed
%   and passed as input to this function. The options structure are used to
%   execute the visualization of the results. In the opened figure, the
%   first chart presents the attracting or repelling slow manifold from the
%   three dimensional perspective, instead the second contains the
%   projection respect to the termination plane.
%
%   @param  S   :   Slow manifold structure.
%   @param opts :   Visualization settings structure.
%
%   @output SFT :   Slow manifold fine tuned structure.
%
% PhD Student Martin Matteo
% University of Padova
% Department of Information Engineering

% ============================ HYERPARAMETERS =============================
% Hyperparameters used inside further code sections.
SFT = S;  CONTINUE = true;

% ============================= FIGURE: RETRIVAL ==========================
% Opening of a new figure where to visualize the results of the procedure.
% Onto this is then created a tiled layout with dedicated spacing.
fig = figure; tiledlayout(1,2,'TileSpacing','tight','Padding','tight'), 
while CONTINUE
    nSF = size(SFT,2); 
    COL = jet; COL = COL(round(linspace(1,size(COL,1),nSF)),:);
    p3D = []; p2D = []; pTXT = [];

    % =========================== VISUALIZATION ===========================
    % Visualization of the three dimensional fine tuned slow manifold
    % inside the first tile of the previously created tile layout. The
    % color used in the different simualtions changes respect to the
    % computation order from the darkest to the lighter.
    nexttile(1)
    for iS = 1:1:nSF
        hold on;
        p3D(iS) = plot3(SFT{iS}.h,SFT{iS}.V,SFT{iS}.s,'Color',COL(iS,:),'LineWidth',1,'LineStyle','-'); 
        hold off; 
        drawnow
    end

    Axes = gca;
    Func_SetGrid(Axes,opts)
    Func_SetAxesFont(Axes,opts)

    % =========================== VISUALIZATION ===========================
    % Visualization of the projected slow manifold onto the considered
    % plane. The visualization is color coded to distinguish the different
    % simulation but are even visualized labels that indicates the
    % computational order.
    nexttile(2)
    for iS = 2:1:nSF
        SEGMENT.x = [SFT{iS-1}.h(end), SFT{iS}.h(end)];
        SEGMENT.y = [SFT{iS-1}.V(end), SFT{iS}.V(end)];
        hold on;
        p2D(iS-1)  = plot(SEGMENT.x, SEGMENT.y,'Color',COL(iS,:),'Marker','.','MarkerSize',5,'LineWidth',1.5);
        pTXT(iS-1) = text(SFT{iS}.h(end),SFT{iS}.V(end),sprintf('%i',iS));
        hold off;
        drawnow
    end

    Axes = gca;
    Func_SetGrid(Axes,opts)
    Func_SetAxesFont(Axes,opts)

    % ================================ REQUEST ============================
    % Request to understand if it is needed to remove simulations from the
    % slow manifold cell array. In case of affermative answer it is
    % requested to the user which simulations to discard.
    REQUEST = input('FINE TUNING BVP - Would you like to remove simulations? [0 - No | 1 - Yes] ');
    if REQUEST == 1
        index = input('FINE TUNING BVP - Which one would you remove? ');
        SFT(index) = []; delete(p3D), delete(p2D), delete(pTXT)
        CONTINUE = true;
    else
        CONTINUE = false;
    end
end

end