function PATTERN = Func_PatternRecognition(TimeSeries,TH)
%
%   PATTERN = Func_PatternRecognition(TimeSeries,TH)
%
%   Function that recognized the knd of pattern specified inside the input
%   TimeSeries to the function. An empirical threshold is used to
%   discriminate between large and small amplitude oscillations.
%
%   @param TimeSeries   :   Time series to be analyzed.
%   @param TH           :   Threshold to discriminate between small and
%                           large amplitude oscillation.
%
%   @output PATTERN     :   Pattern associated to the current analysed time
%                           series.
%
% PhD Student Martin Matteo
% University of Padova
% Department of Information Engineering

M = islocalmax(TimeSeries);
TimeSeriesMax = TimeSeries(M);
TimeSeriesMax = sort(TimeSeriesMax,'ascend');
if TimeSeriesMax(1) <= TimeSeriesMax(end)*TH, PATTERN = 'MMO'; end
if TimeSeriesMax(1) > TimeSeriesMax(end)*TH, PATTERN = 'SPIKING'; end

end