function opts = Func_RetriveOptimizedBoundaries(S,VAR,VARopts,opts,P)
%
%   opts = Func_RetriveOptimizedBoundaries(S,VAR,VARopts,opts,P)
%
%   Function that retrive the optimized boundaries respect to the
%   simulation structure passed as input S. These are then save inside
%   dedicated fields of the opts structure.
%
%   @param S        :   Structure in which the simulation is stored.
%   @param VAR      :   Variable which boundaries should be optimized.
%   @param VARopts  :   Field of the structure opts in which store the
%                       optimized boundaries.
%   @param opts     :   Visualization settings structure.
%   @param P        :   Dilation and contraction percentage.
%
%   @output opts    :   Visualization settings structure.
%
% PhD Student Martin Matteo
% University of Padova
% Department of Information Engineering

% ============================ HYERPARAMETERS =============================
% Hyperparameters used inside further code sections.
nVS = length(VAR);
nVO = length(VARopts);

% ========================== OPTIMIZED BOUNDARIES =========================
% Definition of the optimized boundaries respect to the simulation
% specified as input argument to this function.
for iV = 1:1:nVS
    x = eval(['S.',VAR{iV},';']);
    m = min(x); M = max(x);
    if m < 0, m = m*(1 + P); end
    if m > 0, m = m*(1 - P); end
    if M < 0, M = M*(1 - P); end
    if M > 0, M = M*(1 + P); end
    eval(['opts.',VARopts{iV},' = [m,M];'])
end


end