function opts = Func_RetriveOptimizedBoundaries2(EXP,VAR,VARopts,opts,T,P)
%
%   opts = Func_RetriveOptimizedBoundaries2(EXP,VAR,VARopts,opts,T,P)
%
%   Function that compute the optimized boundaries respect to the
%   experiment maximum and minimum value specified inside the considered
%   simulation. These values are then save inside dedicated structure.
%
%   @param EXP      :   Experiment from which derive information about the
%                       optimized boundaries.
%   @param VAR      :   Variable that needed to be optmized.
%   @param VARopts  :   Variable in which store the optimized boundaries.
%   @param opts     :   Visualization settings structure.
%   @param T        :   Time transient to be neglected.
%   @param P        :   Dilation contraction percentage.
%
%   @output opts    :   Visualization settings structure.
%
% PhD Student Martin Matteo
% University of Padova
% Department of Information Engineering

% ============================ HYERPARAMETERS =============================
% Hyperparameters used inside further code sections.
CTR   = {'Control','Stimulated'};
nCTR  = length(CTR); nVS   = length(VAR); nIApp = length(EXP.Control.IApp);

% ========================== OPTIMIZED BOUNDARIES =========================
% Definition of the optimized boundaries respect to the simulation
% contained inside the passed as input experiment structure.
for iV = 1:1:nVS
    m = 100; M = -100;
    for iCTR = 1:1:nCTR
        for iI = 1:1:nIApp
            S = eval(['EXP.',CTR{iCTR},'.S{iI};']);
            S = Func_CropTime(S,T);
            x = eval(['S.',VAR{iV},';']);
            mT = min(x); MT = max(x);
            if mT < 0, mT = mT*(1 + P); end
            if mT > 0, mT = mT*(1 - P); end
            if MT < 0, MT = MT*(1 - P); end
            if MT > 0, MT = MT*(1 + P); end

            if mT < m, m = mT; end
            if MT > M, M = MT; end
        end
    end
    if m == 0, m = -0.05; end
    eval(['opts.',VARopts{iV},' = [m,M];'])
end


end