function opts = Func_RetriveOptimizedBoundaries3(EXP,iEXP,VAR,VARopts,opts,pathGeometry,fileNameGeometry,P)
%
%   opts = Func_RetriveOptimizedBoundaries3(EXP,iEXP,VAR,VARopts,opts,...
%                           pathGeometry,fileNameGeometry,P)
%
%   Function that compute the optimized boundaries respect to the
%   equilibrium point and the folded singularity associated to a given
%   experiment.
%
%   @param EXP      :   Experiment structure.
%   @param iEXP     :   Index of the experiment from where derive
%                       information.
%   @param VAR      :   Variable respect which derive the optimized
%                       boundaries.
%   @param VARopts  :   Variable to be changed and optimized in terms of
%                       boundaries.
%   @param opts     :   Visualization settings structure.
%   @param pathGeometry     :   Geometry object path string.
%   @param fileNameGeometry :   Geometry file name string.
%   @param P                :   Dilation contraction percentage.
%
%   @output opts    :   Updated visualization settings structure.
%
% PhD Student Martin Matteo
% University of Padova
% Department of Information Engineering

% ============================ HYERPARAMETERS =============================
% Hyperparameters used inside further code sections.
CTR   = {'Control','Stimulated'};
nCTR  = length(CTR); nVS   = length(VAR); nIApp = length(EXP.Control.IApp);

% ========================== OPTIMIZED BOUNDARIES =========================
% Definition of the optimized boundaries respect to the equilibrium and the
% folded singularity of the system considered inside the current
% experiment.
for iV = 1:1:nVS
    m = 100; M = -100;
    for iCTR = 1:1:nCTR
        for iI = 1:1:nIApp
            IApp = EXP.Control.IApp(iI);
            load([pathGeometry,sprintf(fileNameGeometry,iEXP,IApp,CTR{iCTR})],'EQ','FS')
            x = eval(['EQ.',VAR{iV},';']);
            mT = min(x); MT = max(x);
            [m,M] = Func_Comparison(m,M,mT,MT,P);
            x = eval(['FS.',VAR{iV},';']);
            mT = min(x); MT = max(x);
            [m,M] = Func_Comparison(m,M,mT,MT,P);
        end
    end
    if m == 0, m = -0.05; end
    eval(['opts.',VARopts{iV},' = [m,M];'])
end

% ============================ ADDITIONAL FUNCTIONS =======================
% Additional functions used inside the code.

    function [m,M] = Func_Comparison(m,M,mT,MT,P)
        if mT < 0, mT = mT*(1 + P); end
        if mT > 0, mT = mT*(1 - P); end
        if MT < 0, MT = MT*(1 - P); end
        if MT > 0, MT = MT*(1 + P); end

        if mT < m, m = mT; end
        if MT > M, M = MT; end
    end

end