function opts = Func_RetriveOptimizedBoundaries4(EQ,FS,VAR,VARopts,opts,P)
%
%   opts = Func_RetriveOptimizedBoundaries4(EQ,FS,VAR,VARopts,opts,P)
%
%   Function used to retrive the optimized boundaries respect a local
%   visualization where only the local dynamics of the model is
%   investigated close to the equilibrium point (EQ) and the folded 
%   singularity (FS). These information are stored inside the opts
%   structure. To improve the visualization a tuneable parameter P of
%   relative percentage can be specified to create slighly bigger
%   boundaries than the one perfectly matching equilibrium and folded
%   singularity maximum and minimum coordinates.
%
%   @param EQ       :   Equilibrium point structure.
%   @param FS       :   Folded singularity structure.
%   @param VAR      :   Variable used inside the visualization.
%   @param VARopts  :   Variable to be updated inside the opts structure.
%   @param opts     :   Options structure.
%   @param P        :   Dilation percentage.
%
%   @output opts    :   New option visualization structure.
%
% PhD Student Martin Matteo
% Unversity of Padova
% Department of Information Engineering

% ============================= HYPERPARAMETERS ===========================
% Definition of the model hyperparameter used inside the the further-code.
nVS   = length(VAR);

% =========================== BOUNDARIES OPTIMIZATION  ====================
% Boundaries optimization respect to the criterion previously exposed in
% the function description. Optimization of the boundaries first respect to
% the equilibrium point and then respect to the folded singularity
% sequentially.
for iV = 1:1:nVS
    m = eval(['opts.',VARopts{iV},'(1);']);
    M = eval(['opts.',VARopts{iV},'(2);']);
    x = eval(['EQ.',VAR{iV},';']);
    mT = min(x); MT = max(x);
    [m,M] = Func_Comparison(m,M,mT,MT,P(iV));
    x = eval(['FS.',VAR{iV},';']);
    mT = min(x); MT = max(x);
    [m,M] = Func_Comparison(m,M,mT,MT,P(iV));
    if m == 0, m = -0.05; end
    eval(['opts.',VARopts{iV},' = [m,M];'])
end

% =============================== ADDITIONAL FUNCTION =====================
% Additional function used inside the previously proposed code.
    function [m,M] = Func_Comparison(m,M,mT,MT,P)
        if mT < 0, mT = mT*(1 + P); end
        if mT > 0, mT = mT*(1 - P); end
        if MT < 0, MT = MT*(1 - P); end
        if MT > 0, MT = MT*(1 + P); end

        if mT < m, m = mT; end
        if MT > M, M = MT; end
    end

end