function opts = Func_RetriveOptimizedBoundaries5(S,EVENT,opts)
%
%   opts = Func_RetriveOptimizedBoundaries5(S,EVENT,opts)
%
%   Function that retrive the optimized boundaries for the plane projection
%   visualization of the slow manifold S (attracting or repelling) respect
%   to the specified plane inside the event variable EVENTS.
%
%   @param S    :   Slow manifold structure from which derive the optimized
%                   visualization boundaries.
%   @param EVENT:   Event structure respect to which derive the plane
%                   projection and compute the optimized boundaries.
%   @param opts :   Option visualization structure.
%
%   @output opts:   Option visualization structure.
%
% PhD Student Martin Matteo
% University of Padova
% Department of Information Engineering

% ======================== PLANE PROJECTION ===============================
% Retrival of the plane projection respect to the plane identified via the
% EVENT property.
[x,y] = Func_RetriveFromSlowManifold(S,EVENT);

% ======================== OPTIMIZED BOUNDARIES ===========================
% Storage of the optimized boundaries information inside the dedicated opts
% structure.
opts.xlim = [min(x), max(x)]; opts.ylim = [min(y), max(y)];

% ============================ FUNCTIONS ==================================
% Additional functions needed to let the code be more readible.

function [x,y] = Func_RetriveFromSlowManifold(S,EVENT)
    nS = length(S); idx = []; x = zeros(nS,1); y = zeros(nS,1);
    for iS = 1:1:nS
        idx = find(S{iS}.ie == EVENT);
        idx = idx(end);
        x(iS) = eval(['S{iS}.se(idx,1)']);
        y(iS) = eval(['S{iS}.se(idx,2)']);
    end
end

end