function CR = Func_TestingCanardOrbit(C,param)
%
%   CR = Func_TestingCanardOrbit(C,param)
%
%   Function which tests the canard orbit passed as input argument by
%   executing a simple forward simulation of the same.
%
%   @param C        :   Canard orbit to test via a simple forward
%                       simulation.
%   @param param    :   Parameter associated to the model which allows to
%                       simulated the 3D LAV model to check the solutions.
%
%   @output CR      :   Retrived canard orbit via forward simulations.
%
% PhD Student Martin Matteo
% University of Padova
% Department of Information Engineering

% ============================ HYPERPARAMETERS ============================
% Retrival of some hyperparameters to be used inside further code sections.
nC = length(C); nV = length(param.VAR); T = [0, 100];

% ========================== FORWARD SIMULATIONS ==========================
% Forward simulation of the 3D LAV model to check the reliability of the 
% canard orbit obtained via the connection of forward and backward
% projection at the level of the considered plane.
for iC = 1:1:nC
    IC = zeros(nV,1);
    for iV = 1:1:nV, IC(iV) = eval(['C{iC}.',param.VAR{iV},'(1);']); end

    options = odeset('RelTol',1e-12,'AbsTol',1e-12,'Event',@Func_EventODEAPSingle);
    CR{iC} = Func_Simulate(@Func_LAV_3D,T,IC,param.VAR,param,options);
end

end