function Axes = Func_VisualizeCanard(SF,SB,SCF,SCB,VAR)
%
%   Axes = Func_VisualizeCanard(SF,SB,SCF,SCB,VAR)
%
%   Function that visualize the canard computed and passed as argument of
%   the current function. This enable the visualization of the computed
%   canard.
%
%   @param SF   :   Forward slow manifold simulations.
%   @param SB   :   Backward slow manifold simulations.
%   @param SCF  :   Forward canard simulations.
%   @param SBF  :   Backward canard simulations.
%   @param VAR  :   Structure of variables.
%   
%   @output Axes:   Axes of the last chart displayed.
%
% PhD Student Martin Matteo
% University of Padova
% Department of Information Engineering

% ========================= INFORMATION ===================================
% Retrival of the principal information via dedicated functions.
nSF = length(SF); nSB = length(SB); nC  = length(SCF);
COL = jet; COL = COL(round(linspace(1,size(COL,1),nC)),:);

% =========================== WARNINGS ====================================
% Raise of warnings due to the incompatible number of forward and backward
% canard identified.
if not(length(SCB) == length(SCF)), exit('WARNING! - Canard incompatibility!'), end

% ========================== VISUALIZATION ================================
% Visualization of the slow manifold over which are diplayed the canard
% trajectories retrived.
hold on
Func_VisualizeSlowManifold2(SF,'A',VAR,0)
Func_VisualizeSlowManifold2(SB,'R',VAR,0)
hold off
for i = 1:1:nC
    eval(['x = SCF{i}.',VAR{1},';'])
    eval(['y = SCF{i}.',VAR{2},';'])
    eval(['z = SCF{i}.',VAR{3},';'])
    hold on, plot3(x,y,z,'Color',COL(i,:),'LineWidth',1.5), hold off
    eval(['x = SCB{i}.',VAR{1},';'])
    eval(['y = SCB{i}.',VAR{2},';'])
    eval(['z = SCB{i}.',VAR{3},';'])
    hold on, plot3(x(2:end),y(2:end),z(2:end),'Color',COL(i,:),'LineWidth',1.5), hold off
end

Axes = gca;
    

end