function [Axes,p,L] = Func_VisualizeCanard2(fig, C, VARVisual, LineStyles)
%
%   [Axes,p,L] = Func_VisualizeCanard2(fig, C, VARVisual, LineStyles)
%
%   Function that enable the visualization of the canard inside a phase
%   space or as a time series by specifying inside the VARVisual field the
%   set of variable that should be visualized.
%
%   @param fig      :   Figure where to visualize the canard orbits
%   @param C        :   Canard orbits that needed to be visualized.
%   @param VARVisual:   Variables cell array where each entry defines a
%                       variable that should be visualized.
%
%   @output Axes    :   Axes object
%   @output p       :   Line handle to be used for legend creation purposes
%   @output L       :   Legend string associated to the visualized canard
%                       orbits.
%
% PhD Student Martin Matteo
% University of Padova
% Department of Information Engineering

% ========================= FIGURE: RECALLING =============================
% Identification of the figure where to execute the different visualization
% propose in the further sections of this code.
figure(fig);

% ======================= HYPEPARAMETERS: RETRIVAL ========================
% Identification of the hyperparameters needed to execute computations.
nV = length(VARVisual); nC = length(C);
VARRef = {'x','y','z'}; p  = [];

% ============================ INPUT: CHECKING ============================
% Checking the content of the input variables. If any LineStyle attributed
% is passed then are by default automatically set to the continous line
% style.
if nargin == 3
    LineStyles = {}; for iC = 1:1:nC, LineStyles{iC} = '-'; end
end

% ======================== COLOR SCALE: DEFINITION ========================
% Definition of the color scale used in further section of the code to
% visualize the canard objects.
COL = Func_ColorMapCanard(nC); %COL = COL(round(linspace(1,size(COL,1),nC)),:);

for iC = 1:1:nC
    % ===================== VARIABLES: ASSOCIATION ========================
    % Association of the variables between the VARRef structure and the
    % VARVisual. This is done to use the general variables x,y,z inside
    % further section of the code despite more specific ones.
    for iV = 1:1:nV
        eval(sprintf('%s = C{iC}.%s;',VARRef{iV},VARVisual{iV}))
    end

    % ========================= VISUALIZATION: 2D =========================
    % 2D visualization inside a dedicated plane specified inside the
    % VARVisual input cell array.
    if nV == 2
        hold on
        p(iC) = plot(x,y,'Color',COL(iC,:),'LineStyle',LineStyles{iC},'LineWidth',0.8);
        hold off
    end

    % ========================= VISUALIZATION: 3D =========================
    % 3D visualization inside a dedicated plane specified inside the
    % VARVisual input cell array.
    if nV == 3
        hold on
        p(iC) = plot3(x,y,z,'Color',COL(iC,:),'LineStyle',LineStyles{iC},'LineWidth',0.8);
        hold off
    end
    L{iC} = sprintf('$\\xi_%i$',C{iC}.nSAO);
end

% ========================== RETRIVAL: INFORMATION ========================
% Retrival of the information relative to the current visualized axes.
Axes = gca;

end