function [Axes, p, L] = Func_VisualizeEQ(EQ, ColorMod, SizeMod)
%
%   [Axes, p, L] = Func_VisualizeEQ(EQ)
%
%   Function that visualize the equilibrium point specified inside the
%   structure EQ passed as input to the function.
%
%   @param EQ       :   Equilibrium point structure to be visualized.
%   @param special  :   Boolean parameter. If it is set to true then 
%                       special changes the color of the equilibrium.
%
% PhD Student Martin Matteo
% Department of Information Engineering
% University of Padova

if nargin == 1, ColorMod = true; SizeMod = false; end
if nargin == 2, SizeMod = false; end

% =========================== PROPERTIES ==================================
V = double(EQ.V); h = double(EQ.h); s = double(EQ.s); E = double(EQ.E);

% =========================== CLASSIFICATION ==============================
COL = 'r'; MARKER = 's'; MARKERSIZE = 5; L = 'EQ'; 
if any(real(E) > 0), COL = 'k'; MARKER = 's'; end

% ======================== ALTERNATIVE CLASSIFICATION =====================
if ColorMod, COL = [0, 0.8196, 0.7490]; if any(real(E) > 0), COL = [1.0000, 0.5843, 0.0196]; end, end
if SizeMod, MARKERSIZE = 6; end

% =========================== VISUALIZATION ===============================
hold on, 
p = plot3(h,V,s,'LineStyle','none',...
    'Marker',MARKER,'Color',COL,'MarkerSize',MARKERSIZE, 'MarkerFaceColor',COL);
hold off
Axes = gca;

end