function [Axes, p, L] = Func_VisualizeFS(FS, ColorMod, SizeMod)
%
%   [Axes, p, L] = Func_VisualizeFS(FS, special)
%
%   Function that visualize the Folded Singularity point specified inside
%   the FS structure. Different colours are used depending if the
%   considered FS is classified as saddle or node.
%
%   @param FS       :   Structure representative of the folded singularity.
%   @param Special  :   Boolean parameter which if it is not specified is
%                       false. If true activate a costumized color code 
%                       visualization.
%
% PhD Student Martin Matteo
% Department of Information Engineering
% University of Padova

if nargin == 1, ColorMod = false; SizeMod = false; end
if nargin == 2, SizeMod = false; end

% =========================== PROPERTIES ==================================
V = double(FS.V); h = double(FS.h); s = double(FS.s); E = double(FS.E);

% =========================== CLASSIFICATION ==============================
MARKERSIZE = 5; MARKER = 'o'; COL = 'r'; L = 'FN'; 
if any(real(E) > 0), COL = 'k'; MARKER = 'o'; L = 'FS'; end

% ==================== ALTERNATIVE CLASSIFICATION =========================
if ColorMod, COL = 'b'; if any(real(E) > 0), COL = [0.7765, 0.5725, 1.0000]; end, end
if SizeMod, MARKERSIZE = 6; end

% =========================== VISUALIZATION ===============================
hold on,
p = plot3(h,V,s,'LineStyle','none','Marker',MARKER,'Color',COL,'MarkerSize',MARKERSIZE,'MarkerFaceColor',COL);
hold off
Axes = gca;

end