function [Axes, p] = Func_VisualizeLine(L,VAR,COL,LINESTYLE)
%
%   [Axes, p] = Func_VisualizeLine(L,VAR,COL,LINESTYLE)
%
%   Function that visualize the line L passed as input argument to the
%   function itself. The color and the linestyle used for the visualization
%   can be manually specified.
%
%   @param L        :   Line that needed to be visualized.
%   @param VAR      :   Variable cell array. It defines the type of
%                       visualization that needed to be executed.
%   @param COL      :   Color associated to the visualized-line.
%   @param LINESTYLE:   LineStyle associated to the visualized-line.
%
%   @output Axes    :   Axes associated to the plot where the line
%                       visualization has been executed.
%   @output p       :   Line-handle.
%
% PhD Student Martin Matteo
% University of Padova
% Department of Information Engineering

% ======================= INFORMATION: RETRIVAL ===========================
% Retrival of the information that needed to be visualized in the figure.
V = double(L.V); h = double(L.h); s = double(L.s);

% ======================== VARIABLES: MAPPING =============================
% Mapping of the variables inside some dedicated general variables that 
% will be used for the visualization.
nV = length(VAR); VARMapped = {'x','y','z'};
for iV = 1:1:nV, eval([VARMapped{iV},' = ',VAR{iV},';']), end

% =========================== VISUALIZATION ===============================
% Visualization of the considered content.
if nV == 2
    hold on, p = plot(x,y,'LineStyle',LINESTYLE,'Color',COL);    hold off
elseif nV == 3
    hold on, p = plot3(x,y,z,'LineStyle',LINESTYLE,'Color',COL); hold off
end

% ======================== INFORMATION: RETRIVAL ==========================
% Retrival of the information associated to the axes where the last
% visualization has been executed.
Axes = gca;

end