function Func_VisualizePlane2(Plane,opts)
%
%   Func_VisualizePlane2(Plane,opts)
%
%   Function that visualize the plane specified as input parameter of the
%   function. The visualization paradigm is based on creating the real
%   plane surface via the implicit definition of the plane itself.
%
%   @param Plane    :   Structure which contains the properties of the
%                       plane that should be visualized.
%   @param opts     :   Options structure for visualization purposes.
%
% PhD Student Martin Matteo
% Department of Information Engineering
% University of Padova

% ========================== PARAMETER ASSOCIATIONS =======================
a = Plane.a; b = Plane.b; c = Plane.c; d = Plane.d;
fPlane = @(g1,g2,g3,m,n) -g1*m-g2*n-g3;

% =========================== SURFACE COMPUTATION =========================
if a ~= 0 % Expression x = Plane(y,z)
    LBy = opts.ylim(1); UBy = opts.ylim(2);
    LBz = opts.zlim(1); UBz = opts.zlim(2);
    Py  = [LBy, LBy, UBy, UBy];
    Pz  = [LBz, UBz, UBz, LBz];
    g1 = b/a; g2 = c/a; g3 = d/a;
    for i = 1:1:4
        Px(i) = fPlane(g1,g2,g3,Py(i),Pz(i));
    end

end
if b ~= 0 % Expression y = Plane(x,z)
    LBx = opts.xlim(1); UBx = opts.xlim(2);
    LBz = opts.zlim(1); UBz = opts.zlim(2);
    Px  = [LBx, LBx, UBx, UBx];
    Pz  = [LBz, UBz, UBz, LBz];
    g1 = a/b; g2 = c/b; g3 = d/b;
    for i = 1:1:4
        Py(i) = fPlane(g1,g2,g3,Px(i),Pz(i));
    end
end
if c ~= 0 % Expression z = Plane(x,y)
    LBx = opts.xlim(1); UBx = opts.xlim(2);
    LBy = opts.ylim(1); UBy = opts.ylim(2);
    Px  = [LBx, LBx, UBx, UBx];
    Py  = [LBy, UBy, UBy, LBy];
    g1 = a/c; g2 = b/c; g3 = d/c;
    for i = 1:1:4
        Pz(i) = fPlane(g1,g2,g3,Px(i),Py(i));
    end
end

% ============================ VISUALIZATION ==============================
hold on, 
fill3(Px,Py,Pz,'b','FaceColor','b',...
    'FaceAlpha',0.25,'EdgeColor','b','LineWidth',1.5), 
hold off

end