function [Axes, p] = Func_VisualizePlaneProjection2(fig,S,E,COL)
%
%   [Axes, p] = Func_VisualizePlaneProjection2(fig,S,E,COL)
%
%   Function that visualize the plane projection inside the specified
%   figure fig passed as input to this function.
%
%   @param fig  :   Figure where to visualize the plane projection.
%   @param S    :   Set of simulation to plot inside the considered plane.
%   @param E    :   Event to be visualized inside the considered plane.
%   @param COL  :   Color of the visualized curve.
%
%   @output Axes:   Axes where information are presented.
%   @output p   :   Plot handle to generate the legend of the chart.
%
% PhD Student Martin Matteo
% University of Padova
% Department of Information Engineering

% =========================== FIGURE: RETRIVAL ============================
% Retrival of the figure where to execute the visualization of the
% information passed as input argument to the function.
figure(fig);

% ======================= HYPERPARAMETERS: RETRIVAL =======================
% Retrival of the foundamental hypeparameters to be used in further steps.
nS = length(S); xV = zeros(nS,1); yV = zeros(nS,1);

% ======================== X and Y: POPULATION ============================
% Population of the previously initialized vector xV and yV via the
% projection towards the plane identified by the event E of the simulations
% passed as input argument to the function.
for iS = 1:1:nS
    idx = find(S{iS}.ie == E,1,'last');
    x   = S{iS}.se(idx,2);
    y   = S{iS}.se(idx,1);
    hold on, text(x,y,sprintf('%i',iS)), hold off
    xV(iS) = x;
    yV(iS) = y;
end

% =============================== VISUALIZATION ===========================
% Visualization of the previously extracted informations of simulations
% plane projections.
hold on
p = plot(xV,yV,'Color',COL,'LineStyle','-','LineWidth',1.2,...
    'Marker','.','MarkerSize',1.2);
hold off

% ========================== INFORMATION: RETRIVAL ========================
% Retrival of the axes information.
Axes = gca;

end