function [Axes, p, L] = Func_VisualizePoint(P,VAR,Type,Special)
%
%   [Axes, p, L] = Func_VisualizePoint(P,VAR,Type,Special)
%
%   Function that visualize the point P passed as input argument to the
%   function. The typology of the point is passed as input argument
%   together with the set of variables VAR that should be visualized.
%
%   @param P        :   Point structure to be displayed.
%   @param VAR      :   Variable cell array to be visualized.
%   @param Type     :   Typology of the point that it is passed as input.
%   @param Special  :   Boolean value associated to a special colouring of 
%                       folded and ordinary singularities.
%
%   @output Axes    :   Axes object of the current visualized plot.
%   @output p       :   Point handle to be used to create legend.
%   @output L       :   Legend string item descriptive of the input passed
%                       point.
%
% PhD Student Martin Matteo
% University of Padova
% Department of Information Engineering

if nargin == 3, Special = false; end

% =========================== PROPERTIES ==================================
% Retrival of point properties via the extraction using the structure
% notation. The V,h and s variable identified variables to be visualized
% instead E the eigenvalues associated to the previous considered point.
V = double(P.V); h = double(P.h); s = double(P.s); 
if strcmp(Type,'EQ') || strcmp(Type,'FS'), E = double(P.E); end

% =========================== CLASSIFICATION ==============================
% Classification of the point that it is needed to be visualized depending
% on the eigenvalues of the input passed structure.
if strcmp(Type,'EQ'),   COL = 'r'; MARKER = 's'; L = 'EQ'; if any(real(E) > 0), COL = 'k'; MARKER = 's'; end, end
if strcmp(Type,'FS'),   COL = 'r'; MARKER = 'o'; L = 'FN'; if any(real(E) > 0), COL = 'k'; MARKER = 'o'; end, end
if strcmp(Type,'GN'),   COL = 'm'; MARKER = '^'; L = 'GN'; end
if strcmp(Type,'GNT1'), COL = 'g'; MARKER = 's'; L = 'GNT1'; end
if strcmp(Type,'GNT2'), COL = 'k'; MARKER = '*'; L = 'GNT2'; end
if strcmp(Type,'EQ') && Special, COL = [0, 0.8196, 0.7490]; if any(real(E) > 0), COL = [1.0000, 0.5843, 0.0196]; end, end
if strcmp(Type,'FS') && Special, COL = 'b'; if any(real(E) > 0), COL = [0.7765, 0.5725, 1.0000]; end, end

% =============================== VARIABLES ===============================
% Variables that needed to be visualized inside the current specified plot.
nV = length(VAR); VARMapped = {'x','y','z'};
for iV = 1:1:nV, eval([VARMapped{iV},' = ',VAR{iV},';']), end

% =========================== VISUALIZATION ===============================
% Visualization of the input passed plot. If the variables specified are 2
% just a bidimensional visualization is performed instead the visualization
% inside a three dimesional one will be made.

if nV == 2 
    hold on,
    p = plot(x,y,'LineStyle','none',...
    'Marker',MARKER,'Color',COL,'MarkerSize',5, 'MarkerFaceColor',COL);
    hold off
elseif nV == 3
    hold on, 
    p = plot3(x,y,z,'LineStyle','none',...
        'Marker',MARKER,'Color',COL,'MarkerSize',5, 'MarkerFaceColor',COL);
    hold off
end

% ============================= INFORMATION: RETRIVAL =====================
% Retrival of the information associated to the current visualized axes
% inside the open figure. These are stored inside the Axes variable.
Axes = gca;

end