function [Axes,p,L] = Func_VisualizeSimulationPS(fig,EXP,VAR,CTRL,IApp)
% 
%   [Axes,p,L] = Func_VisualizeSimulationPS(fig,EXP,VAR,CTRL,IApp)
%
%   Function that visualize the simulation inside the phase space where the
%   axes are made up with the variable inside the VAR structure.
%
%   @param fig  :   Figure where to visualize the model behaviour
%   @param EXP  :   Experiment of which evolution should be visualized
%   @param VAR  :   Structure containing the variable to be visualized
%                   inside the phase space, the order is important, the
%                   first will be displayed on x, the second on y and the
%                   third on z respectively.
%   @param CTRL :   Control term which could be both Control and Stimulated
%                   but even not something else to discriminate between 
%                   the necessity of visualizing just the Control, the
%                   Stimulated or both the experiment evolution.
%   @param IApp :   Applied current for which the simulation is visualized.
%
%   @output Axes:   Axes of the current created plot
%   @output p   :   Line handle to be used to create legend of the chart
%   @output L   :   String associated to the experimental simulation
%                   visualized.
%
% PhD Student Martin Matteo
% University of Padova
% Department of Information Engineering

% ========================= INFORMATION EXTRACTION ========================
% Extraction of the information that needed to be visualized inside the
% following step.
VARToVisualize = {'x','y','z'}; nVAR = length(VAR);
if not(strcmp(CTRL,'Control') || strcmp(CTRL,'Stimulated'))
    eval(['iS = find(EXP.Control.IApp == IApp);']) 
    for iVAR = 1:1:nVAR
        eval(['C.',VARToVisualize{iVAR},' = EXP.Control.','S{iS}.',VAR{iVAR},';']);
        eval(['S.',VARToVisualize{iVAR},' = EXP.Stimulated.','S{iS}.',VAR{iVAR},';']);
    end
    SIM = {'C','S'}; COL = ['k';'r'];
else
    eval(['iS = find(EXP.',CTRL,'.IApp == IApp);'])
    for iVAR = 1:1:nVAR
        eval(['B.',VARToVisualize{iVAR},' = EXP.',CTRL,'.','S{iS}.',VAR{iVAR},';']);
    end
    if strcmp(CTRL,'Control'),    COL = 'k'; end
    if strcmp(CTRL,'Stimulated'), COL = 'r'; end
    SIM = {'B'};
end

% ============================= VISUALIZATION =============================
% Visualization of the previously retrived information inside a dedicated
% chart.
nSIM = length(SIM);
for i = 1:1:nSIM
    for iVAR = 1:1:nVAR
        eval([VARToVisualize{iVAR},' = ',SIM{i},'.',VARToVisualize{iVAR},';'])
    end

    L = 'Trajectory';
    hold on,
    if nVAR == 3, p = plot3(x,y,z,'Color',COL(i),'LineStyle','-','LineWidth',1); end
    if nVAR == 2, p = plot(x,y,'Color',COL(i),'LineStyle','-','LineWidth',1); end
    hold off
end

Axes = gca;
end