function Func_VisualizeSlowManifold(S,Type,VAR)
%
%   Func_VisualizeSlowManifold(S,Type,VAR)
%
%   Function that visualize the slow manifold content inside the S
%   structure passed as input to the function. The visualization occurs
%   inside a 3D phase space where the x,y,z axes are set up with the
%   variables specified inside VAR.
%
%   @param S    :   Slow manifold structure
%   @param Type :   Type of slow manifold that should be visualized. This
%                   parameter could be set to 'A' or 'R' respectively for
%                   attracting and repelling subsets.
%   @param VAR  :   Variables sets that specify the x, y and z axes of the
%                   opened graphic window.
%
% PhD Student Martin Matteo
% Department of Information Engineering
% University of Padova

nS = length(S);

% =========================== COLOR SELECTION =============================
if strcmp(Type,'A'), COL = 'k'; end
if strcmp(Type,'R'), COL = 'r'; end

% ======================= MANIFOLD VISUALIZATION ==========================
for i = 1:1:nS
    eval(['x = S{i}.',VAR{1},';'])
    eval(['y = S{i}.',VAR{2},';'])
    eval(['z = S{i}.',VAR{3},';'])
    hold on,
    L = plot3(x,y,z,'Color',COL,'LineWidth',1.5,'LineStyle','-');
    L.Color(4) = 0.05;
    hold off
end

% ================= PLANE INTERSECTION VISUALIZATION ======================
clear x y z
for i = 1:1:nS
    eval(['x(i) = S{i}.',VAR{1},'(end);'])
    eval(['y(i) = S{i}.',VAR{2},'(end);'])
    eval(['z(i) = S{i}.',VAR{3},'(end);'])
end
hold on, plot3(x,y,z,'Color',COL,'LineWidth',2,'LineStyle','-'), hold off

end