function opts = Func_ZoomEQFS(VAR,VARopts,opts,FS,EQ)
%
%   opts = Func_ZoomEQFS(VAR,VARopts,opts,FS,EQ)
%
%   Function that tune the boundaries of the x and y axes such that the
%   core section of the visualization is around the equilibrium and the
%   folded singularity of the system.
%
%   @param VAR      :   Varible to evaluate of both FS and EQ
%   @param VARopts  :   Variable to update inside the opts structure
%   @param opts     :   Option structure
%   @param FS       :   Folded singularity structure
%   @param EQ       :   Equilibrium point of the system
%
%   @output opts    :   Option structure with updated VARopts fields
%
% PhD Student Martin Matteo
% University of Padova
% Department of Information Engineering

% ======================= HYPEPARAMETERS: IDENTIFICATION ==================
% Identification of some hypeparameters to allow the code to be more
% readable inside further section.
nV = length(VAR);

% ========================= BOUNDARIES: IDENTIFICATION ====================
% Identification of the boundaries by first initializating empirically the
% maximum and minimum value M and m respectively to non-feasible value and
% then updating these boundaries following a simple readible rationale.
% First the equilibrium properties are inspected then the same analyses are
% run for the folded singularity. At the end of the scan the information
% are saved inside the opts structure.
for iV=1:1:nV
    m = 100; M = -100;
    x = eval(['EQ.',VAR{iV}]);
    if x < m, m = x; end
    if x > M, M = x; end
    x = eval(['FS.',VAR{iV}]);
    if x < m, m = x; end
    if x > M, M = x; end
    eval(['opts.',VARopts{iV},' = [m,M];']);
end

end