function Axes = Func_VisualizePlaneProjection(S,VAR,COL,LINE)
%
%   Axes = Func_VisualizePlaneProjection(S,VAR,COL,LINE)
%
%   Visualization of the plane projections inside a dedicated set up plane
%   which x and y axis variable are passed as input to this function.
%
%   @param S    :   Projection over the target plane of slow manifold.
%   @param VAR  :   Variable represenetative of variables that should be
%                   visualized over the x and y axes of the chart.
%   @param COL  :   Color exploited for the visualization.
%   @param LINE :   Line Style to set up correctly the visualization of the
%                   different lines.
%
%   @output Axes:   Axes objet.
%
% PhD Student Martin Matteo
% Department of Information Engineering
% University of Padova

% ============================ HYPERPARAMETERS ============================
% Definition of code hyperparameters used inside further step of code.
nS = length(S); if nargin == 3, LINE = '-'; end

% =========================== VISUALIZATION ===============================
% Visualization of the information displayed inside the previously opened
% figure before the calling of this function. Generation first of the
% vector to be visualized and then visualization of the same inside the
% dedicated graphic window.
hold on,
for i = 1:1:nS
    eval(['x1(',num2str(i),') = S{',num2str(i),'}.',VAR{1},';'])
    eval(['x2(',num2str(i),') = S{',num2str(i),'}.',VAR{2},';'])
end
plot(x1,x2,'LineStyle',LINE,'Marker','.','MarkerSize',5,'Color',COL)
hold off

% ========================== RETRIVAL: INFORMATION ========================
% Retrival of the axes information associated to the figure where the last
% plot has been made.
Axes = gca;

end